<?php 
      require("./conf.php");
      netzbrett_cookies();
      $pagetype = "content";
      $pagetitle = "Resolution of anaphoric reference (message board)";
      include "http://www.coli.uni-sb.de/common_start.html" ?>

<tr>

<!-- Navbar -->

<td width="150" bgcolor="#efefef" align="left" valign="top"> 
<!--navi-bar to be included on all pages-->
<table border=0>
<tr>
<td> 
	<a href="../index.phtml">Course home</a>
</td>
</tr>

<tr>
<td>
	<a href="../schedule.phtml">Schedule</a>

</td>
</tr>

<tr>
<td>
	<a href="../software.phtml">Software</a>
</td>
</tr>

<tr>
<td>
	<a href="../corpus.phtml">Corpus</a>
</td>

</tr>


<tr>
<td>
	<a href="messages.phtml">Message Board</a>
</td>
</tr>

<tr>
<td>
	<a href="../annotation.phtml">Annotation</a>
</td>
</tr>


<tr>   
<td>
	<a href="../biblio.phtml">Literature</a>

</td>
</tr>

<tr>   
<td>
	<a href="../links.phtml">Links</a>
</td>
</tr>


</table></td>


<!-- Main -->

<td align="left" valign="top">
<div class="main">

<h1>Anaphoric Reference Resolution</h1>

<b><a href="http://www.coli.uni-sb.de/~korbay/">Ivana Kruijff-Korbayova</a> 
</b>
<p>
<i>Projektseminar. Computerlinguistik, 2. Studienabschnitt</i><br>
<i>Wednesday, 11-13, Geb.17.2, Konferenzraum (2.11)</i>

<h2>Message board</h2>

<? 
 echo netzbrett_main(); 
?>

</div>
</td>
</tr>

<?php 
      $whoami = basename($PHP_SELF);
      $modtime = strftime("%Y-%m-%d", filemtime($whoami));
      $pwuid_record = posix_getpwuid(fileowner($whoami));
      $modname = $pwuid_record["name"];
      $contactmail = 'mailto:korbay@<delete the space>coli.uni-sb.de';

      include "http://www.coli.uni-sb.de/common_end.html" ?>
