<?php
/**
* Sample index file for the Netzbrett  
*
* @author	Thomas Weinert	<subjective@subjective.de>
* @version	1.4.6
* @package  Netzbrett
* @modulegroup    Netzbrett_Sample
* @module   Netzbrett_Sample_Index
*/

/**
* Include the Configuration
*/
 require("./conf.php");
 netzbrett_cookies();
?>
<html>
<head>
<title>subjective.de - netzbrett in action</title>
</head>
<body bgcolor="#FFFFFF" text="#000000" alink="#000000" link="#004080" vlink="#808080">
<? 
 echo netzbrett_main(); 
?>
</div>
</body>
</html>
