<?php
/**
* Configuration file for the Netzbrett  
*
* @author	Thomas Weinert	<subjective@subjective.de>
* @version	1.4.6
* @package  Netzbrett
* @modulegroup    Netzbrett_Program
* @module   Netzbrett_Program_Conf
*/

 //Import mode for Netzbrett 1.2.x (true/false)
 $importmode = false;
 
  //Kind of data ("text","text_fast","mysql","pear")
 $sck = "text";
 
 //Textmode: Directory for data files must be read/writeable
 $data_dir = "./data/";
 
 //MySQL: Host;Database;Table;User;Password
 #$data_dir = "localhost;netzbrett;netzbrett;user;password";
 
 //Pear: URI;Table  
 #$data_dir = "mysql://user:pass@localhost/netzbrett;netzbrett";
 
 //Period for higlight new messages
 $max_entrynew = 3;
 //Display period for messages 
 /*
  1 = today
  2 = one day
  3 = two days
  8 = one week
  15 = two weeks
  31 = one month
  61 = two months
  10000 = all 
 */
 $std_showentry = 15;
 //Language (de, en, it, ...
 $nb_lngpath = "./lng/";
 $nb_lng="en";
 
 /*Calendar mode 
   "B.E." = Buddhism Era
   "C.E." = Cristian Era (default)
   "THAI" = Thai Calendar */
 //$datemode = "B.E.";
 $datemode = "C.E.";
 //$datemode = "THAI";
 //Formatstring for the date - C.E. only
 $datefmt = "d.m.Y";
 //Formatstring for the time 
 $timefmt = "H:i";
 
 //Color mode - color follows indent (true/false)
 $colorfollow = false;
 //Color 1
 $color_1 = "#EFF3F7";
 //Color 2
 $color_2 = "#D8E0F9";
 
 //Table width
 $table_width = 545;
 //Table with for left column (icons)
 $lcol_width = 50;
 //Show left column (true/false)
 $lcol_show = false;

 //Allowed HTMLtags seperated by ;
 $tags_allowed = "<b>;</b>;<i>;</i>";
 //Escape tags (or delete) (true/false)
 $comment_tags = true;
 //Hide WWW-Field
 $hide_wwwinput = true;
 
 //Perform a strong check for inputs (Latin 1 charset only) (true/false)
 $perform_strongcheck = false;
 
 //After save back to index (or show entry) (true/false)
 $backtoindex = false;
 //Send new entries per mail
 $sendnews = false;
 $sendnews_cc = false;
 //Send changed entries (true/false)
 $sendchanged = false; 
 //To?
 $sendto = "name@domain.de";
 $sendto_cc = "name_cc@domain.de";
 //With subject?
 $sendsubj = "New Entry in the Netzbrett";
 //Set cookie with user data (true/false)
 $usercookie = true;
 //life period for the cookie in days
 $usercookiedays = 14;
 
 //Use Admin mode (true/false)
 $adminmode = true;
 //Admin password 
 $adminpass = "keinaweiss";
 
 //Webpath to the pictures
 $webpicpath = "pics_ie/";
  
 //Pictures
 $pic_refresh = $webpicpath."akt.gif";
 $pic_artikel = $webpicpath."artikel.gif";
 $pic_artikel_new = $webpicpath."artikel_new.gif";
 $pic_artikel_sel = $webpicpath."artikel_sel.gif";
 $pic_artnew = $webpicpath."artnew.gif";
 $pic_artone = $webpicpath."artikelo.gif";
 $pic_artmore = $webpicpath."artikelou.gif";
 $pic_makenew = $webpicpath."artikeln.gif";
 $pic_moveall = $webpicpath."moveall.gif";
 $pic_moveup = $webpicpath."moveup.gif";
 $pic_pass = $webpicpath."login.gif";
 $pic_delete = $webpicpath."delete.gif";
 $pic_printer = $webpicpath."printer.gif";
 
 $pic_trenner = $webpicpath."trenner.gif";
 
 //position of thread navigation
 //before entry
 $navontop = true;
 //after entry
 $navonbottom = true;

 //different templates
 //entry in thread list
 $tpl_rowstart = '<font size="-1" face="Arial, Verdana, Helvetica">';
 $tpl_rowend = '</font>';
 //actual entry in thread list
 $tpl_rowstart_hl = '<font size="-1" face="Arial, Verdana, Helvetica"><b>';
 $tpl_rowend_hl = '</b></font>';
 //name in thread list
 $tpl_namestart = '<i>';
 $tpl_nameend = '</i>';
 
 $tpl_errorsign = '<b style="color:#FF0000;">!!!</b>';
 
 //input field width 
 $tpl_sizeinput = 40;
 $tpl_colstextarea = 50;
 $tpl_rowstextarea = 20;
 
 //Direkte Ausgabe (true/false)
 $nb_direct_output=true;
 
 //this params are added to links "param1;param2"
 $nb_query_params = "";
 
 //Columns (Maximum indent in a thread) 
 $vmax = 50;
 
 //Do not change after this line ...
 
 //different script files
 /**
 * Program Main File
 */
 require("netzbr.php");
 /**
 * Function for input checks
 */
 require("chkit.php");

 //the different socket files
 switch ($sck) {
  case "text_fast" : $sck_file = ("sck_text_fast.php"); break;
  case "mysql" : $sck_file = ("sck_mysql.php"); break;
  case "pear" : $sck_file = ("sck_pear.php"); break;
  default : $sck_file = ("sck_text.php");
 }
 //include socket
 include("$sck_file"); 
?>
