###############################################
#                                             #
# MySQL create dump for the netzbrett         #
#                                             #
# Filename : mysql.sql                        #
# Author   : Thomas Weinert                   #
# Homepage : http://www.subjective.de         #
# Licence  : GPL (see licence.txt)            #
###############################################



CREATE TABLE netzbrett (
   FILE bigint(20) NOT NULL auto_increment,
   DATE int(10) unsigned NOT NULL,
   HTTP tinytext NOT NULL,
   MAIL tinytext NOT NULL,
   NAME tinytext NOT NULL,
   PATH tinytext NOT NULL,
   PREV tinytext NOT NULL,
   SUBJ text NOT NULL,
   TEXT mediumtext NOT NULL,
   PRIMARY KEY (FILE)
);

